﻿using Model;
using Newtonsoft.Json;

namespace Vo
{
    /// <summary>
    /// Treeselect树结构实体类
    /// </summary>
    public class TreeSelectVo
    {
        /// <summary>
        /// 节点Id
        /// </summary>
        public long Id { get; set; }
        /// <summary>
        /// 节点名称
        /// </summary>
        public string Name { get; set; }
        public long ParentId { get; set; }
        public string MenuType { get; set; }
        public string Path { get; set; }
        public int SortOrder { get; set; }
        public TreeSelectMeta Meta { get; set; }
        public List<string> Permission { get; set; }

        public TreeSelectVo() { }

        public TreeSelectVo(SysMenu menu)
        {
            Id = menu.MenuId;
            Name = menu.Name;
            ParentId = menu.ParentId;
            MenuType = menu.MenuType;
            Path = menu.Path;
            SortOrder = menu.SortOrder;
            Meta = new TreeSelectMeta();
            Meta.Title = menu.Name;
            Meta.Icon = menu.Icon;
            Permission = new List<string>();

            List<TreeSelectVo> child = new List<TreeSelectVo>();
            foreach (var item in menu.Children)
            {
                if(item.MenuType == "0")
                {
                    child.Add(new TreeSelectVo(item));
                }
                else
                {
                    Permission.Add(item.Permission);
                }
            }

            Children = child;
        }

        public TreeSelectVo(SysDept dept)
        {
            Id = dept.DeptId;
            Name = dept.Name;

            List<TreeSelectVo> child = new List<TreeSelectVo>();
            foreach (var item in dept.children)
            {
                child.Add(new TreeSelectVo(item));
            }

            Children = child;
        }

        [JsonProperty(NullValueHandling = NullValueHandling.Ignore)]
        public List<TreeSelectVo> Children { get; set; }
    }

    public class TreeSelectMeta
    {
        public string Title { get; set; }
        public string Icon { get; set; }
        public List<string> Roles { get; set; }
        public List<string> Auths { get; set; }
    }
}
